GEOWatch MLops Example
======================

NOTE: These docs are sparse and need to be expanded.

This folder contains a minimal example of how to use the GeoWATCH MLOps
pipeline system. Look into the ``mlops_example_module/pipelines.py`` file to
see examples of pipeline definitions, and ``run_pipeline.sh`` for how to
execute pipelines and aggregate results.

Other Demo Locations:


There is also a demo integrated into the code at
:func:`geowatch.mlops.pipeline_nodes:demodata_pipeline` that is run in CI
testing.

See Also:

* ~/code/geowatch/tests/test_mlops_scheduler.py
* ~/code/geowatch/geowatch/mlops/pipeline_nodes.py
* ~/code/geowatch/tests/test_mlops_pipeline.py


Slides: https://docs.google.com/presentation/d/1mZJCGXZT6ekfj3KZ7gTFiBa3Sj8Y8hsP2YlvHaYbrAM/edit#slide=id.g30a42d1df1d_0_141
